Dagian
======
.. image:: https://img.shields.io/travis/ianlini/dagian/master.svg
   :target: https://travis-ci.org/ianlini/dagian
.. image:: https://img.shields.io/pypi/v/dagian.svg
   :target: https://pypi.org/project/dagian/
.. image:: https://img.shields.io/pypi/l/dagian.svg
   :target: https://pypi.org/project/dagian/
